<?php

namespace Drupal\block_visibility_groups_admin;

use Drupal\block_visibility_groups\GroupEvaluator;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Executable\ExecutableManagerInterface;

/**
 * Information about a group.
 *
 * @package Drupal\block_visibility_groups_admin
 */
class GroupInfo implements GroupInfoInterface {

  /**
   * The group evaluator.
   *
   * @var \Drupal\block_visibility_groups\GroupEvaluator
   */
  protected $groupEvaluator;

  /**
   * The entity storage system for block visibility groups.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $groupStorage;

  /**
   * The condition manager.
   *
   * @var \Drupal\Core\Executable\ExecutableManagerInterface
   */
  protected $conditionManager;

  /**
   * Constructor.
   *
   * @param \Drupal\block_visibility_groups\GroupEvaluator $group_evaluator
   *   The group evaluator.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_manager
   *   The entity manager.
   * @param \Drupal\Core\Executable\ExecutableManagerInterface $condition_manager
   *   The condition manager.
   */
  public function __construct(GroupEvaluator $group_evaluator, EntityTypeManagerInterface $entity_manager, ExecutableManagerInterface $condition_manager) {
    $this->groupEvaluator = $group_evaluator;
    $this->groupStorage = $entity_manager->getStorage('block_visibility_group');
    $this->conditionManager = $condition_manager;
  }

  /**
   * Get all active groups.
   *
   * @return \Drupal\block_visibility_groups\Entity\BlockVisibilityGroup[]
   *   A list of active groups.
   */
  public function getActiveGroups() {
    $active_groups = [];
    /** @var BlockVisibilityGroup $group */
    foreach ($this->groupStorage->loadMultiple() as $id => $group) {
      /** @var \Drupal\block_visibility_groups\Plugin\Condition\ConditionGroup $condition ; */
      $condition = $this->conditionManager->createInstance('condition_group', ['block_visibility_group' => $id]);
      if ($condition->evaluate()) {
        $active_groups[$id] = $group;
      }
    }
    return $active_groups;
  }

}
